﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Win32;

namespace CompassHealth.NAntExtensions.Tasks
{
    /// <summary>
    /// Utility class for reading and writing to the windows registry.
    /// </summary>
    internal static class RegistryUtilities
    {
        /// <summary>
        /// Reads a value from the Windows registry and returns as a string.
        /// </summary>
        /// <param name="subKey">The subkey in which the value resides.</param>
        /// <param name="name">The value name to read from.</param>
        /// <returns>A string representation of the value contained in the supplied subkey.</returns>
        internal static string GetRegistryEntry(string subKey, string name)
        {
            string returnVal = string.Empty;

            RegistryKey key = Registry.CurrentUser.CreateSubKey(subKey);
            
            returnVal = key.GetValue(name, string.Empty).ToString();

            return returnVal;
        }

        /// <summary>
        /// Writes a value to the Windows registry and returns as a string.
        /// </summary>
        /// <param name="subKey">The subkey in which the value resides.</param>
        /// <param name="name">The value name to write to.</param>
        /// <param name="value">The value to write to the supplied subkey and value name.</param>
        internal static void WriteRegistryEntry(string subKey, string name, string value)
        {
            RegistryKey key = Registry.CurrentUser.CreateSubKey(subKey);
            key.SetValue(name, value);
        }
    }
}
