﻿using System;
using System.Collections.Generic;
using System.Security.Cryptography;
using System.Text;

using NAnt.Core;
using NAnt.Core.Attributes;


namespace CompassHealth.NAntExtensions.Tasks
{
    /// <summary>
    /// This class handles retrieving Vault username and passwords from the current user.
    /// </summary>
    [TaskName("VaultLoginGet")]
    public class VaultLoginGet : Task
    {
        protected override void ExecuteTask()
        {
            const string vaultLoginSubKey = @"Software\Compass Health\VaultLogin\";
            this.Log(Level.Info, "Starting Vault Login Query");

            // Retrieve the vault username from the registry //
            VaultUser.GetSingleton().UserName = RegistryUtilities.GetRegistryEntry(vaultLoginSubKey, "UserName");
            
            // Retrieve the encrypted password from the registry
            string passwordCipher = RegistryUtilities.GetRegistryEntry(vaultLoginSubKey,"Password");
            byte[] passwordCipherBytes = Convert.FromBase64String(passwordCipher);
            
            // Set the password to an empty length string in case something fails using the retrieval or decryptiong //
            VaultUser.GetSingleton().Password = string.Empty;   
            
            try
            {
                // use the ProtectedData class to unencrypt the password using the current windows users unique credentials //
                // note that we don't have to supply any encryption password, this is handled internally by this class based //
                // on internal windows user information //
                byte[] passwordPlainTextBytes = ProtectedData.Unprotect(passwordCipherBytes, null, DataProtectionScope.CurrentUser);
                UnicodeEncoding encoding = new UnicodeEncoding();
                VaultUser.GetSingleton().Password = encoding.GetString(passwordPlainTextBytes);
            }
            catch (CryptographicException ex)
            {
                // do nothing , the password will be set to an empty length string //
            }

            
            // Display the login dialogue if there is incomplete authentication detail //
            if (String.IsNullOrEmpty(VaultUser.GetSingleton().UserName) | String.IsNullOrEmpty(VaultUser.GetSingleton().Password))
            {
                this.Log(Level.Verbose, "Incomplete authentication information retrieved. Requesting user input ...");
                VaultLoginForm form = new VaultLoginForm();
                form.ShowDialog();
            }

            this.Log(Level.Info, "Clearing existing authentication detail");

            // set the registry entries to blank until we are sure that they work for logging in  - the corresponding VaultLoginSave task will need to be called from the script //
            RegistryUtilities.WriteRegistryEntry(vaultLoginSubKey, "UserName", string.Empty);
            RegistryUtilities.WriteRegistryEntry(vaultLoginSubKey, "Password", string.Empty);
        }

    }

}
