﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Security.Cryptography;

using NAnt.Core;
using NAnt.Core.Attributes;

namespace CompassHealth.NAntExtensions.Tasks
{
    /// <summary>
    /// This class handles saving Vault authentication details. Password details are encrypted.
    /// </summary>
    [TaskName("VaultLoginSave")]
    public class VaultLoginSave : Task
    {
        protected override void ExecuteTask()
        {
            const string vaultLoginSubKey = @"Software\Compass Health\VaultLogin\";

            this.Log(Level.Info, "Saving authentication detail");
            RegistryUtilities.WriteRegistryEntry(vaultLoginSubKey, "UserName", VaultUser.GetSingleton().UserName);

            System.Text.UnicodeEncoding encoding = new UnicodeEncoding();
            byte[] passwordPlainTextBytes = encoding.GetBytes(VaultUser.GetSingleton().Password);

            // use the ProtectedData class to encrypt the password using the current windows users unique credentials //
            // note that we don't have to supply any encryption password, this is handled internally by this class based //
            // on internal windows user information //
            byte[] passwordCipherBytes = ProtectedData.Protect(passwordPlainTextBytes, null, DataProtectionScope.CurrentUser);
            string passwordCipher = Convert.ToBase64String(passwordCipherBytes);

            RegistryUtilities.WriteRegistryEntry(vaultLoginSubKey, "Password", passwordCipher);
        }
    }
}
