﻿using System;
using System.Collections.Generic;
using System.Text;

namespace CompassHealth.NAntExtensions.Tasks
{
    /// <summary>
    /// This singleton class handles storage of authentication details for the current user.
    /// </summary>
    internal class VaultUser
    {
        private string _userName = string.Empty;
        private string _password = string.Empty;

        private static VaultUser singelton;
        private static object _syncLock = new object();

        private VaultUser()
        {
            // no implementation, just set private so it cannot be invoked from outside this class //
        }

        public static VaultUser GetSingleton()
        {
            // lock the object to prevent possible threading problems if ever used in multi-threading environment //
            lock(_syncLock)
            {
                if (singelton == null)
                {
                    singelton = new VaultUser();
                }
            }
            return singelton;
        }

        /// <summary>
        /// The Vault username for the current user.
        /// </summary>
        public string UserName
        {
            get { return _userName; }
            set { _userName = value; }
        }

        /// <summary>
        /// The Vault password for the current user.
        /// </summary>
        public string Password
        {
            get { return _password; }
            set { _password = value; }
        }


    }
}
